from rgbprint import Color, gradient_print


def error(message):
    gradient_print(message, start_color=Color.red, end_color=Color.deep_pink)

def emphasis(message, intensity = 1):
    if intensity == 1:
        gradient_print(message, start_color=0xf1cb85, end_color=0xe786dd)
    if intensity == 2:
        gradient_print(message, start_color=0x7274f9, end_color=0xb5f7f6)

def feedback(message):
    gradient_print(message, start_color=Color.lime, end_color=Color.green)

def neutral(message):
    gradient_print(message, start_color=0xd0a7ca, end_color=0xcdb996)

def indent(number):
    return "    " * number


from imaginaition.imaginaition_logging import *

def run(args: list):
    if (len(args) == 2):
        emphasis("Imaginaition Help:")
        neutral(indent(1) + "-h, --help, help: Shows this help page. Welcome! Run help <app> to see the help page for each app.\n")
        emphasis(indent(1) + "Apps:", 2)
        emphasis(indent(2) + "cut: Cuts videos in a folder", 2)
        emphasis(indent(2) + "imagine: [Development] Uses Stable Diffusion in the cloud to generate an image.", 2)
        exit()

    if args[2] == "cut":
        emphasis("Imaginaition Help: cut")
        neutral(indent(1) + "cut <folder>: Cuts all videos in a folder and puts them in a folder called cut-videos")
        
    if args[2] == "imagine":
        emphasis("Imaginaition Help: imagine")
        neutral(indent(1) + "imagine <image> [args]: Uses Stable Diffusion in the cloud to generate an image.")
        neutral(indent(2) + "--style-override, -so: Overrides the default Imagainaition style.")


from imaginaition.imaginaition_logging import *
import sys
from rgbprint import gradient_print, Color
import imaginaition.cut
import imaginaition.help

def main():
    appName = None
    try:
        appName = sys.argv[1]
    except:
        pass

    if appName == None:
        error("No app name provided")
        exit()

    help_commands = ["help", "--help", "-h"]
    if appName in help_commands:
        imaginaition.help.run(sys.argv)

    if appName == "cut":
        emphasis("Running app: cut")
        imaginaition.cut.run(sys.argv)

if __name__ == "__main__":
    main()


import glob
import os
from imaginaition.imaginaition_logging import *
import subprocess


def get_videos_in_folder(folder: str):
    extensions = ['.mp4', '.avi', '.mov', '.m4v', '.mkv']  # add more extensions as needed
    video_files = []
    for ext in extensions:
        video_files.extend(glob.glob(os.path.join(folder, f'*{ext}')))
    return video_files


def run(arguments: list):
    input_folder = None
    try:
        input_folder = arguments[2]
    except:
        error("No input folder provided")
        exit()
    if input_folder:
        videos = get_videos_in_folder(input_folder)
        for video in videos:
            try:
                feedback(f"Cutting video: {video}")
                os.makedirs("./cut-videos", exist_ok=True)
                subprocess.run(["auto-editor", f"{video}", "--margin", "0.05sec", "-o", f"./cut-videos/{os.path.basename(video)}"], check=True)
            except Exception as e:
                error(f"Error cutting video: {e}")
        neutral("Finished cutting videos. Import them into your favourite editor :D")



from setuptools import setup, find_packages

setup(
    name='imaginaition',
    version='0.1.0',
    author='jtpotato',
    author_email='',
    description='Imagination and technology for a better world.',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'imaginaition=imaginaition.__main__:main',
        ],
    },
    install_requires=["auto-editor", "rgbprint"],
)
